import re


def clean_html(self, text: str) -> str:
    """
    Метод clean_html убирает все символы HTML из текста

    return re.sub('<[^<]+?>', '', text) - возвращает текст без элементов HTML

    Параметры
    ------
        '<[^<]+?>' - шаблон для определения элементов HTML
        '' - на что заменяются элементы html
    """
    return re.sub('<[^<]+?>', '', text)



import re

def clean_spaces(self, text: str) -> str:

    """
    Метод clean_spaces убирает лишние пробелы из текста

        re.sub(r' +', ' ', text) - Ищет в переданном тексте лишние пробелы, заменяет их на один пробел
        return text.strip() - Возвращает готовый текст убирая лишние пробелы

        Параметры
        ------
            r' +' - шаблон поиска множества пробелов
            ' ' - на что заменять множества пробелов
            text - сама строка, в которой ищем множества пробелов
    """

    text = re.sub(r'[\uFE00-\uFE0F]', ' ', text)
    text = re.sub('[\t\r\n]', ' ', text)
    text = re.sub(r' +', ' ', text)
    text = re.sub(r'\xa0+', ' ', text)
    return text



def to_lower_text(self, text: str) -> str:

    """
    Метод to_lower_text меняет все заглавные символы в тексте на прописные

    return text.lower() - Возвращает текст с заменеными в нем заглывными буквами на прописные
    """

    return text.lower()



import string


def clean_punctuation(self, text: str) -> str:
    """
    Метод clean_puctuation убирает все знаки припинания из текста

    return ''.join(i for i in text if i not in string.punctuation) - возвращает текст без пунктуационных знаков 
    """
    text = text.replace('-', ' ')
    return ''.join(i for i in text if i not in string.punctuation)




import nltk
nltk.download('stopwords')
from nltk.corpus import stopwords


def clean_stopwords(self, text: str) -> str:

    """
    Метод clean_stopwords убирает все стоп слова

    stop_words = set(stopwords.words('russian')) - Получает список стоп слов

    words = text.split(' ') - Слова заменяет на пробелы

    for word in words:
        answer += word if word not in stop_words else ''
        answer += ' '
    Убирает стоп слова из текста
    """

    stop_words = set(stopwords.words('russian'))
    words = text.split(' ')
    answer = ''
    for word in words:
        answer += word if word not in stop_words else ''
        answer += ' '

    return answer.strip()



import pymorphy2


def text_to_morphems(self, text: str) -> str:

    """
    Метод text_to_morphems заменяет слова на морфемы

    morph = pymorphy2.MorphAnalyzer(lang='ru') - получает список морфем

    for i in text.split(' '):
        mor += morph.parse(i)[0].normal_form
        mor += ' '
    Цикл в катором слова заменяются на морфемы и разделяются пробелом
    """

    morph = pymorphy2.MorphAnalyzer(lang='ru')
    mor = ''
    for i in text.split(' '):
        mor += morph.parse(i)[0].normal_form
        mor += ' '
    return mor



from ._to_lower import to_lower_text
from ._emoji_cleaner import clean_emoji
from ._spaces_cleaner import clean_spaces
from ._html_cleaner import clean_html
from ._punctuation_cleaner import clean_punctuation
from ._clean_stopwords import clean_stopwords
from ._to_morpheme import text_to_morphems

from .TextCleaner import TextCleaner



from src.ru_text_cleaner import TextCleaner
from src.ru_text_cleaner import clean_punctuation
import re

t = TextCleaner(spaces=False)

test = 'Какая-то форматирования-нибудь строка-либо то-то'

print(clean_punctuation(None, text=test))
print(t.clean_text(test))


from . import *


class TextCleaner:
    def __init__(self, spaces=True, punctuation=True, html=True, emoji=True, lower=True,
                 stop_words=True, morpheme=True):

        """
        Метод __init__ инциализирует экземпляр класса TextCleaner

        self.spaces = spaces - Необходимо ли удалять пробелы
        self.punctuation = punctuation - Необходимо ли удалять пунктуацию
        self.html = html - Необходимо ли удалять теги HTML
        self.emoji = emoji - Необходимо ли удалять Emoji
        self.lower = lower - Необходимо ли переводить текст в нижний регистр
        self.stopwords = stop_words - Необходимо ли удалять стоп слова
        self.morpheme = morpheme - Необходимо ли заменять слова на морфемы

        """

        self.spaces = spaces
        self.punctuation = punctuation
        self.html = html
        self.emoji = emoji
        self.lower = lower
        self.stopwords = stop_words
        self.morpheme = morpheme

        self.to_lower = to_lower_text
        self.clean_emoji = clean_emoji
        self.clean_punctuation = clean_punctuation
        self.clean_html = clean_html
        self.clean_space = clean_spaces
        self.clean_stopwords = clean_stopwords
        self.to_morpheme = text_to_morphems

    def clean_text(self, text: str) -> str:

        """ Метод clean_text форматирует текст в зависимости от поставленных флагов"""

        if self.lower:
            text = self.to_lower(self, text)
        if self.emoji:
            text = self.clean_emoji(self, text)
        if self.html:
            text = self.clean_html(self, text)
        if self.punctuation:
            text = self.clean_punctuation(self, text)
        if self.stopwords:
            text = self.clean_stopwords(self, text)
        if self.morpheme:
            text = self.to_morpheme(self, text)
        if self.spaces:
            text = self.clean_space(self, text)

        return text
